@@ -8,7 +8,7 @@
 %  make/0, and to improve usability when using the XPCE profiler and XPCE
 %  graphical debugger
 %
-%  Last updated on February 13, 2015
+%  Last updated on August 2, 2015
 %
 %  This program is free software: you can redistribute it and/or modify
 %  it under the terms of the GNU General Public License as published by
@@ -691,6 +691,11 @@ user:portray(c(This, Entity, Rest)) :-
 :- meta_predicate user:'$lgt_object_property'(*,*,*,*,*,*,*,*).
 :- meta_predicate user:'$lgt_object_property_resources'(*,*,*,*,*,*).
 :- meta_predicate user:'$lgt_object_property_resource'(*,*,*,*,*,*).
+:- meta_predicate user:'$lgt_protocol_property_resources'(*,*,*,*,*).
+:- meta_predicate user:'$lgt_protocol_property_resource'(*,*,*,*,*).
+:- meta_predicate user:'$lgt_category_property_resource'(*,*,*,*,*).
+:- meta_predicate user:'$lgt_category_property_resources'(*,*,*,*,*).
+
 :- meta_predicate user:'$lgt_assert_pred_def'(*,*,*,*,*,*,*,*).
 :- meta_predicate user:'$lgt_send_to_self_nv'(*,*,*).
 
