@@ -4,7 +4,7 @@
 %  Copyright (c) 1998-2015 Paulo Moura <pmoura@logtalk.org>
 %
 %  Adapter file for tuProlog 2.9.0 and later versions
-%  Last updated on February 13, 2015
+%  Last updated on May 10, 2015
 %
 %  This program is free software: you can redistribute it and/or modify
 %  it under the terms of the GNU General Public License as published by
@@ -243,7 +243,7 @@ numbervars(Term, From, Next) :-
 '$lgt_prolog_feature'(prolog_version, (Major, Minor, Path)) :-
 	?????
 '$lgt_prolog_feature'(prolog_compatible_version, '@>='((2, 9, 0))).
-'$lgt_prolog_feature'(prolog_conformance, iso_lax).
+'$lgt_prolog_feature'(prolog_conformance, lax).
 
 '$lgt_prolog_feature'(encoding_directive, unsupported).
 '$lgt_prolog_feature'(tabling, unsupported).
